esp_eth_phy_new_generic

Function esp_eth_phy_new_generic 

pub unsafe extern "C" fn esp_eth_phy_new_generic(
    config: *const eth_phy_config_t,
) -> *mut esp_eth_phy_s
@brief Create a PHY instance of generic chip which conforms with IEEE 802.3

@note Default reset timing configuration is set conservatively( @c DEFAULT_PHY_RESET_ASSERTION_TIME_US ). If you need faster response and your chip supports it, configure it via @c config parameter.

@warning While basic functionality should always work, some specific features might be limited, even if the PHY meets IEEE 802.3 standard. A typical example is loopback functionality, where certain PHYs may require setting a specific speed mode to operate correctly.

@param[in] config configuration of PHY @return - instance: create PHY instance successfully - NULL: create PHY instance failed because some error occurred