pub unsafe extern "C" fn esp_http_client_request_send(
client: *mut esp_http_client,
write_len: i32,
) -> i32Expand description
@brief Send HTTP request headers and data This function sends the HTTP request line, headers, and any post data to the server.
@param[in] client The esp_http_client handle @param[in] write_len Length of data to write (for POST/PUT requests)
@return
- ESP_OK on successful
- ESP_FAIL on error
- ESP_ERR_HTTP_WRITE_DATA if write operation fails