pub unsafe extern "C" fn esp_log_va(
config: esp_log_config_t,
tag: *const u8,
format: *const u8,
args: *mut c_void,
)Expand description
@brief Logs a formatted message using the provided log message configs and a variable argument list.
@param config Configuration and level of the log message. @param tag The tag string used to indicate the component from which to log. It is also used to check whether logging is enabled for that tag (depends on CONFIG_LOG_TAG_LEVEL_IMPL). If NULL then the tag is not printed. @param format The format string for the log message. @param args List of arguments.