esp_sleep_get_wakeup_cause

Function esp_sleep_get_wakeup_cause 

pub unsafe extern "C" fn esp_sleep_get_wakeup_cause() -> u32
@brief Get the wakeup source which caused wakeup from sleep

@note !!! This API will only return one wakeup source. If multiple wakeup sources wake up at the same time, the wakeup source information may be lost.

@return cause of wake up from last sleep (deep sleep or light sleep)