heap_caps_register_failed_alloc_callback

Function heap_caps_register_failed_alloc_callback 

pub unsafe extern "C" fn heap_caps_register_failed_alloc_callback(
    callback: Option<unsafe extern "C" fn(usize, u32, *const u8)>,
) -> i32
@brief registers a callback function to be invoked if a memory allocation operation fails @param callback caller defined callback to be invoked @return ESP_OK if callback was registered.