heap_caps_walk_all

Function heap_caps_walk_all 

pub unsafe extern "C" fn heap_caps_walk_all(
    walker_func: Option<unsafe extern "C" fn(walker_heap_info, walker_block_info, *mut c_void) -> bool>,
    user_data: *mut c_void,
)
@brief Function called to walk through all heaps defined by the heap component

@param walker_func Callback called for each block of the heaps being traversed @param user_data Opaque pointer to user defined data