protocomm_get_sec_version

Function protocomm_get_sec_version 

pub unsafe extern "C" fn protocomm_get_sec_version(
    pc: *mut protocomm,
    sec_ver: *mut i32,
    sec_patch_ver: *mut u8,
) -> i32
@brief Get the security version of the protocomm instance

This API will return the security version of the protocomm instance.

@param[in] pc Pointer to the protocomm instance @param[out] sec_ver Pointer to the security version @param[out] sec_patch_ver Pointer to the security patch version

@return

  • ESP_OK : Success
  • ESP_ERR_INVALID_ARG : Null instance/name arguments