uart_set_baudrate

Function uart_set_baudrate 

pub unsafe extern "C" fn uart_set_baudrate(
    uart_num: u32,
    baudrate: u32,
) -> i32
@brief Set desired UART baud rate.

Note that the actual baud rate set could have a slight deviation from the user-configured value due to rounding error.

@param uart_num UART port number, the max port number is (UART_NUM_MAX -1). @param baudrate UART baud rate.

@return - ESP_FAIL Parameter error, such as baud rate unachievable - ESP_OK Success