uart_vfs_dev_port_set_rx_line_endings

Function uart_vfs_dev_port_set_rx_line_endings 

pub unsafe extern "C" fn uart_vfs_dev_port_set_rx_line_endings(
    uart_num: i32,
    mode: u32,
) -> i32
@brief Set the line endings expected to be received on specified UART

This specifies the conversion between line endings received on UART and newlines (ā€˜\n’, LF) passed into stdin:

  • ESP_LINE_ENDINGS_CRLF: convert CRLF to LF
  • ESP_LINE_ENDINGS_CR: convert CR to LF
  • ESP_LINE_ENDINGS_LF: no modification

@note this function is not thread safe w.r.t. reading from UART

@param uart_num the UART number @param mode line endings to send to UART

@return 0 if succeeded, or -1 when an error (specified by errno) have occurred.