#[repr(C)]pub struct esp_vfs_select_ops_t {
pub start_select: Option<unsafe extern "C" fn(i32, *mut fd_set, *mut fd_set, *mut fd_set, esp_vfs_select_sem_t, *mut *mut c_void) -> i32>,
pub socket_select: Option<unsafe extern "C" fn(i32, *mut fd_set, *mut fd_set, *mut fd_set, *mut timeval) -> i32>,
pub stop_socket_select: Option<unsafe extern "C" fn(*mut c_void)>,
pub stop_socket_select_isr: Option<unsafe extern "C" fn(*mut c_void, *mut i32)>,
pub get_socket_select_semaphore: Option<unsafe extern "C" fn() -> *mut c_void>,
pub end_select: Option<unsafe extern "C" fn(*mut c_void) -> i32>,
}Expand description
@brief Struct containing function pointers to select related functionality.
Fields
start_select: Option<unsafe extern "C" fn(i32, *mut fd_set, *mut fd_set, *mut fd_set, esp_vfs_select_sem_t, *mut *mut c_void) -> i32>start_select is called for setting up synchronous I/O multiplexing of the desired file descriptors in the given VFS
socket_select: Option<unsafe extern "C" fn(i32, *mut fd_set, *mut fd_set, *mut fd_set, *mut timeval) -> i32>socket select function for socket FDs with the functionality of POSIX select(); this should be set only for the socket VFS
stop_socket_select: Option<unsafe extern "C" fn(*mut c_void)>called by VFS to interrupt the socket_select call when select is activated from a non-socket VFS driver; set only for the socket driver
stop_socket_select_isr: Option<unsafe extern "C" fn(*mut c_void, *mut i32)>stop_socket_select which can be called from ISR; set only for the socket driver
get_socket_select_semaphore: Option<unsafe extern "C" fn() -> *mut c_void>end_select is called to stop the I/O multiplexing and deinitialize the environment created by start_select for the given VFS
end_select: Option<unsafe extern "C" fn(*mut c_void) -> i32>get_socket_select_semaphore returns semaphore allocated in the socket driver; set only for the socket driver