temperature_sensor_config_t__bindgen_ty_1

Struct temperature_sensor_config_t__bindgen_ty_1 

#[repr(C)]
pub struct temperature_sensor_config_t__bindgen_ty_1 { pub allow_pd: u32, }

Fields

allow_pd: u32

< If set, the driver will backup/restore the temperature sensor registers before/after entering/exist sleep mode. By this approach, the system can power off temperature sensor’s power domain. This can save power, but at the expense of more RAM being consumed