twai_general_config_t__bindgen_ty_1

Struct twai_general_config_t__bindgen_ty_1 

#[repr(C)]
pub struct twai_general_config_t__bindgen_ty_1 { pub sleep_allow_pd: u32, }

Fields

sleep_allow_pd: u32

< Set to allow power down. When this flag set, the driver will backup/restore the TWAI registers before/after entering/exist sleep mode. By this approach, the system can power off TWAI’s power domain. This can save power, but at the expense of more RAM being consumed.