#[repr(C)]pub struct wifi_tx_rate_config_t {
pub phymode: u32,
pub rate: u32,
pub ersu: bool,
pub dcm: bool,
}Expand description
@brief Argument structure for wifi_tx_rate_config
Fields
phymode: u32< Phymode of specified interface
rate: u32< Rate of specified interface
ersu: bool< Using ERSU to send frame, ERSU is a transmission mode related to 802.11 ax. ERSU is always used in long distance transmission, and its frame has lower rate compared with SU mode
dcm: bool< Using dcm rate to send frame