wpa_crypto_funcs_t

Struct wpa_crypto_funcs_t 

#[repr(C)]
pub struct wpa_crypto_funcs_t { pub size: u32, pub version: u32, pub hmac_sha256_vector: Option<unsafe extern "C" fn(*const u8, i32, i32, *mut *const u8, *const i32, *mut u8) -> i32>, pub pbkdf2_sha1: Option<unsafe extern "C" fn(*const u8, *const u8, u32, i32, *mut u8, u32) -> i32>, pub aes_128_encrypt: Option<unsafe extern "C" fn(*const u8, *const u8, *mut u8, i32) -> i32>, pub aes_128_decrypt: Option<unsafe extern "C" fn(*const u8, *const u8, *mut u8, i32) -> i32>, pub omac1_aes_128: Option<unsafe extern "C" fn(*const u8, *const u8, usize, *mut u8) -> i32>, pub ccmp_decrypt: Option<unsafe extern "C" fn(*const u8, *const u8, *const u8, usize, *mut usize, bool) -> *mut u8>, pub ccmp_encrypt: Option<unsafe extern "C" fn(*const u8, *mut u8, usize, usize, *mut u8, i32, *mut usize) -> *mut u8>, pub aes_gmac: Option<unsafe extern "C" fn(*const u8, usize, *const u8, usize, *const u8, usize, *mut u8) -> i32>, pub sha256_vector: Option<unsafe extern "C" fn(usize, *mut *const u8, *const usize, *mut u8) -> i32>, }
@brief The crypto callback function structure used by esp_wifi. The structure can be set as software crypto or the crypto optimized by device’s hardware.

Fields

size: u32

< The crypto callback function structure size

version: u32

< The crypto callback function structure version

hmac_sha256_vector: Option<unsafe extern "C" fn(*const u8, i32, i32, *mut *const u8, *const i32, *mut u8) -> i32>

< The SHA256 callback function used by esp_wifi

pbkdf2_sha1: Option<unsafe extern "C" fn(*const u8, *const u8, u32, i32, *mut u8, u32) -> i32>

< SHA1-based key derivation function (PBKDF2) callback function for IEEE 802.11

aes_128_encrypt: Option<unsafe extern "C" fn(*const u8, *const u8, *mut u8, i32) -> i32>

< The AES 128 encrypt callback function used by esp_wifi

aes_128_decrypt: Option<unsafe extern "C" fn(*const u8, *const u8, *mut u8, i32) -> i32>

< The AES 128 decrypt callback function used by esp_wifi

omac1_aes_128: Option<unsafe extern "C" fn(*const u8, *const u8, usize, *mut u8) -> i32>

< One-Key CBC MAC (OMAC1) hash with AES-128 callback function for MIC computation

ccmp_decrypt: Option<unsafe extern "C" fn(*const u8, *const u8, *const u8, usize, *mut usize, bool) -> *mut u8>

< Decrypt data callback function using CCMP

ccmp_encrypt: Option<unsafe extern "C" fn(*const u8, *mut u8, usize, usize, *mut u8, i32, *mut usize) -> *mut u8>

< Encrypt data callback function using CCMP

aes_gmac: Option<unsafe extern "C" fn(*const u8, usize, *const u8, usize, *const u8, usize, *mut u8) -> i32>

< One-Key GMAC hash callback function with AES for MIC computation

sha256_vector: Option<unsafe extern "C" fn(usize, *mut *const u8, *const usize, *mut u8) -> i32>

< SHA256 hash callback function for data vector