pub unsafe extern "C" fn esp_sleep_get_wakeup_causes() -> u32Expand description
@brief Get all wakeup sources bitmap which caused wakeup from sleep.
@return The bitmap of the wakeup sources of the last wakeup from sleep. (deep sleep or light sleep)
pub unsafe extern "C" fn esp_sleep_get_wakeup_causes() -> u32@brief Get all wakeup sources bitmap which caused wakeup from sleep.
@return The bitmap of the wakeup sources of the last wakeup from sleep. (deep sleep or light sleep)