pub unsafe extern "C" fn esp_vfs_dump_registered_paths(
fp: *mut __sFILE,
)Expand description
@brief Dump all registered FSs to the provided FILE*
Dump the FSs in the format:
@verbatim
where: index : internal index in the table of registered FSs (the same as returned when registering fd with id) VFS Path Prefix : file prefix used in the esp_vfs_register call or “NULL” VFS entry ptr : pointer to the esp_vfs_fs_ops_t struct used internally when resolving the calls @endverbatim
@param fp File descriptor where data will be dumped