pub unsafe extern "C" fn sdm_channel_disable(
chan: *mut sdm_channel_t,
) -> i32Expand description
@brief Disable the Sigma Delta channel
@note This function will do the opposite work to the sdm_channel_enable()
@param[in] chan SDM channel created by sdm_new_channel
@return
- ESP_OK: Disable SDM channel successfully
- ESP_ERR_INVALID_ARG: Disable SDM channel failed because of invalid argument
- ESP_ERR_INVALID_STATE: Disable SDM channel failed because the channel is not enabled yet
- ESP_FAIL: Disable SDM channel failed because of other error