pub unsafe extern "C" fn wifi_prov_mgr_keep_ble_on(
is_on_after_ble_stop: u8,
) -> i32Expand description
@brief Keep the BLE on after provisioning
This API is used to specify whether the BLE should remain on after the provisioning process has stopped.
This must be called before starting provisioning, i.e. before making a call to wifi_prov_mgr_start_provisioning(), otherwise the default behavior will be used.
@note The value being pointed to by the argument must be valid at least until provisioning is started. Upon start, the manager will store an internal copy of this value, and this data can be freed or invalidated afterwards.
@param[in] is_on_after_ble_stop A boolean indicating if BLE should remain on after provisioning
@return
- ESP_OK : Success
- ESP_ERR_INVALID_ARG : Null argument